==> service_drones_dart-1.0.0.tar.gz: lib/src/data/version1/DroneV1.dart <==
import 'package:pip_services3_commons/pip_services3_commons.dart';

import 'LocationV1.dart';

class DroneV1 implements IStringIdentifiable {
  @override
  String? id;
  String? type;
  String? ownerId;
  String? ownerName;
  String? label;
  String? vendor;
  String? model;
  String? serial;
  int? range;
  LocationV1? base;
  DateTime? registered;
  bool? electric;
  bool? infraRed;
  bool? nightVision;
  bool? fixedCamera;
  bool? tempSensor;
  String? videoUrl;

  DroneV1(
      {this.id,
      this.type,
      this.ownerId,
      this.ownerName,
      this.label,
      this.vendor,
      this.model,
      this.serial,
      this.range,
      this.base,
      this.registered,
      this.electric,
      this.infraRed,
      this.nightVision,
      this.fixedCamera,
      this.tempSensor,
      this.videoUrl});

  void fromJson(Map<String, dynamic> json) {
    id = json['id'];
    type = json['type'];
    ownerId = json['owner_id'];
    ownerName = json['owner_name'];
    label = json['label'];
    vendor = json['vendor'];
    model = json['model'];
    serial = json['serial'];
    range = json['range'];
    base = LocationV1(lat: json['base']?['lat'], long: json['base']?['long']);
    registered = json['registered'];
    electric = json['electric'];
    infraRed = json['infra_red'];
    nightVision = json['night_vision'];
    fixedCamera = json['fixed_camera'];
    tempSensor = json['temp_sensor'];
    videoUrl = json['video_url'];
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'id': id,
      'type': type,
      'owner_id': ownerId,
      'owner_name': ownerName,
      'label': label,
      'vendor': vendor,
      'model': model,
      'serial': serial,
      'range': range,
      'base': {'lat': base?.lat, 'long': base?.long, 'alt': base?.alt},
      'registered': registered,
      'electric': electric,
      'infra_red': infraRed,
      'night_vision': nightVision,
      'fixed_camera': fixedCamera,
      'temp_sensor': tempSensor,
      'video_url': videoUrl,
    };
  }
}

==> service_drones_dart-1.0.1.tar.gz: lib/src/data/version1/DroneV1.dart <==
import 'package:pip_services3_commons/pip_services3_commons.dart';

import 'LocationV1.dart';

class DroneV1 implements IStringIdentifiable {
  @override
  String? id;
  String? type;
  String? ownerId;
  String? ownerName;
  String? label;
  String? vendor;
  String? model;
  String? serial;
  int? range;
  LocationV1? base;
  DateTime? registered;
  bool? electric;
  bool? infraRed;
  bool? nightVision;
  bool? fixedCamera;
  bool? tempSensor;
  String? videoUrl;

  DroneV1(
      {this.id,
      this.type,
      this.ownerId,
      this.ownerName,
      this.label,
      this.vendor,
      this.model,
      this.serial,
      this.range,
      this.base,
      this.registered,
      this.electric,
      this.infraRed,
      this.nightVision,
      this.fixedCamera,
      this.tempSensor,
      this.videoUrl});

  void fromJson(Map<String, dynamic> json) {
    id = json['id'];
    type = json['type'];
    ownerId = json['owner_id'];
    ownerName = json['owner_name'];
    label = json['label'];
    vendor = json['vendor'];
    model = json['model'];
    serial = json['serial'];
    range = json['range'];
    base = LocationV1(lat: json['base']?['lat'], long: json['base']?['long']);
    registered =
        json['registered'] != null ? DateTime.parse(json['registered']) : null;
    electric = json['electric'];
    infraRed = json['infra_red'];
    nightVision = json['night_vision'];
    fixedCamera = json['fixed_camera'];
    tempSensor = json['temp_sensor'];
    videoUrl = json['video_url'];
  }

  Map<String, dynamic> toJson() {
    return <String, dynamic>{
      'id': id,
      'type': type,
      'owner_id': ownerId,
      'owner_name': ownerName,
      'label': label,
      'vendor': vendor,
      'model': model,
      'serial': serial,
      'range': range,
      'base': {'lat': base?.lat, 'long': base?.long, 'alt': base?.alt},
      'registered': registered?.toIso8601String(),
      'electric': electric,
      'infra_red': infraRed,
      'night_vision': nightVision,
      'fixed_camera': fixedCamera,
      'temp_sensor': tempSensor,
      'video_url': videoUrl,
    };
  }
}
